@@ -67,10 +67,13 @@ edit_project <- function(project,
   ###########################################
   # Handling of current_owner, corresp_auth, and creator
   if (is.null(current_owner)) {
-    if (any(authors$remove == project$current_owner)) {
+    if (
+      !is.na(project$current_owner) &&
+      any(authors$remove == project$current_owner)
+    ) {
       current_owner <- new_projects_author(NA)
     }
-  } else {
+  } else if (!is.na(current_owner)) {
     current_owner <-
       validate_projects_author(
         x             = current_owner,
@@ -99,10 +102,13 @@ edit_project <- function(project,
 
 
   if (is.null(corresp_auth)) {
-    if (any(authors$remove == project$corresp_auth)) {
+    if (
+      !is.na(project$corresp_auth) &&
+      any(authors$remove == project$corresp_auth)
+    ) {
       corresp_auth <- new_projects_author(NA)
     }
-  } else {
+  } else if (!is.na(corresp_auth)) {
     corresp_auth <-
       validate_projects_author(
         x             = corresp_auth,
@@ -119,10 +125,10 @@ edit_project <- function(project,
     # author list of the user-specified project
     if (!any(authors$add == corresp_auth)) {
       validate_assoc(
-        x           = corresp_auth,
-        what        = "author",
+        x          = corresp_auth,
+        what       = "author",
         rds_table  = authors_table,
-        what2       = "project",
+        what2      = "project",
         rds_table2 = filtered_assoc
       )
     }
@@ -130,10 +136,10 @@ edit_project <- function(project,
 
 
   if (is.null(creator)) {
-    if (any(authors$remove == project$creator)) {
+    if (!is.na(project$creator) && any(authors$remove == project$creator)) {
       creator <- new_projects_author(NA)
     }
-  } else {
+  } else if (!is.na(creator)) {
     creator <-
       validate_projects_author(
         x             = creator,
@@ -141,8 +147,6 @@ edit_project <- function(project,
         na.ok         = FALSE
       )
   }
-  ###########################################
-  ###########################################
 
   new_project_row <-
     edit_metadata(
@@ -162,7 +166,7 @@ edit_project <- function(project,
       table_path = projects_path
     )
 
-  if (length(authors$remove) > 0) {
+  if (length(authors$remove) > 0L) {
     assoc_table <-
       delete_assoc(
         assoc_table = assoc_table,
@@ -215,8 +219,8 @@ edit_project <- function(project,
   )
 
   if (
-    !is.na(title) ||
-    !is.na(corresp_auth) ||
+    !is.null(title) ||
+    !is.null(corresp_auth) ||
     !identical(authors, list(add = list(), remove = list()))
   ) {
     message("\nHeader has changed. Reprint it with:\nheader(", project$id, ")")
